@@ -135,6 +135,11 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
     model depending on the relative energy along the center-of-mass line for the process
     **AB(i) + P -> A + B + P**
 
+    **Note** if integrating over the crosssection, the integration must be performed not from :math:`0` to
+    :math:`\\infty`, but from :math:`g_{min}` to :math:`\\infty` (because the crosssection is discontinuous),
+    where :math:`g_{min}` is the minimum value of the dimensionless velocity at which the crosssection is non-zero,
+    it can be calculated using the min_dimensionless_vel_diss function
+
     Parameters
     ----------
     g : float
@@ -160,7 +165,34 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
     float
         The dissociation crosssection
     """
-    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss, center_of_mass, vl_dependent)
+    return raw_crosssection_diss_rigid_sphere(g, T, idata[1], molecule.vibr[i], molecule.diss, center_of_mass,
+                                              vl_dependent)
+
+
+def min_dimensionless_vel_diss(T: float, molecule: MoleculeSTS, i: int, vl_dependent: bool=True) -> float:
+    """Calculates the minimum value of the dimensionless relative velocity of colliding particles for which
+    the dissociation crosssection is not zero for the process **AB(i) + P -> A + B + P**
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule : Molecule
+        the molecule which dissociates
+    i : int
+        the vibrational level from which the molecule dissociates (if ``vl_dependent``
+        is ``False``, can be any value)
+    vl_dependent : bool, optional
+        if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
+        molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+
+    Returns
+    -------
+    float
+        The minimum value of the dimensionless relative velocity
+
+    """
+    return raw_min_dimensionless_vel_diss(T, molecule.vibr[i], molecule.diss, vl_dependent)
 
 
 def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
@@ -288,11 +320,6 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
     -------
     float
         The generalized omega integral over the dissociation crosssection
-
-    Raises
-    ------
-    KineticlibError
-        if ``deg > 1``
     """
     return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
                                           vl_dependent, nokt)
@@ -674,6 +701,11 @@ def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecul
     model depending on the relative energy along the center-of-mass line for the process
     **AB(i) + P -> A + B + P**, *raw* version
 
+    **Note** if integrating over the crosssection, the integration must be performed not from :math:`0` to
+    :math:`\\infty`, but from :math:`g_{min}` to :math:`\\infty` (because the crosssection is discontinuous),
+    where :math:`g_{min}` is the minimum value of the dimensionless velocity at which the crosssection is non-zero,
+    it can be calculated using the min_dimensionless_vel_diss function
+
     Parameters
     ----------
     g : float
@@ -713,6 +745,36 @@ def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecul
             return constants.pi * (sigma ** 2)
 
 
+def raw_min_dimensionless_vel_diss(T: float, molecule_vibr: float, molecule_diss: float,
+                                   vl_dependent: bool=True) -> float:
+    """Calculates the minimum value of the dimensionless relative velocity of colliding particles for which
+    the dissociation crosssection is not zero for the process **AB(i) + P -> A + B + P**, *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    molecule_vibr : float
+        the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
+        is ``False``, can be any value)
+    molecule_diss : float
+        the dissociation energy of the molecule which dissociates
+    vl_dependent : bool, optional
+        if ``True``, the dissociation crosssection takes into account the vibrational energy of the dissociating
+        molecule, if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+
+    Returns
+    -------
+    float
+        The minimum value of the dimensionless relative velocity
+
+    """
+    if vl_dependent:
+        return ((molecule_diss - molecule_vibr) / (constants.k * T)) ** 0.5
+    else:
+        return (molecule_diss / (constants.k * T)) ** 0.5
+
+
 def elastic_omega_g_only_vss(g: float, deg: int, vsso: float) -> float:
     """Calculates the velocity-dependent part of the integrand of the
     generalized elastic omega integral for the VSS model
@@ -931,7 +993,6 @@ def raw_vv_integral(T: float, deg: int, mass: float, beta: float, vssc: float, v
     ------
     KineticlibError
         if ``i_delta == 0``
-
     """
     if i_delta != 0:
         f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
@@ -1001,7 +1062,6 @@ def raw_vv_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float,
     ------
     KineticlibError
         if ``i_delta == 0``
-
     """
     if i_delta != 0:
         f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, ve_before1, ve_after1, ve_before2,
@@ -1057,32 +1117,40 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float
     -------
     float
         The generalized omega integral over the dissociation crosssection
-
-    Raises
-    ------
-    KineticlibError
-        if ``deg > 1``
     """
-    if not nokt:
-        multiplier = constants.pi * (sigma ** 2) * ((constants.k * T / (2 * constants.pi * mass)) ** 0.5)
-    else:
-        multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
     if vl_dependent:
         min_sq = (molecule_diss - molecule_vibr) / (constants.k * T)
     else:
         min_sq = molecule_diss / (constants.k * T)
-    if deg == 0:
-        if not center_of_mass:
-            return 0.5 * multiplier * np.exp(-min_sq)
+
+    if not center_of_mass:
+        if not nokt:
+            multiplier = constants.pi * (sigma ** 2) * ((constants.k * T / (2 * constants.pi * mass)) ** 0.5)
         else:
+            multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
+
+        if deg == 0:
             return 0.5 * multiplier * (min_sq + 1.0) * np.exp(-min_sq)
-    elif deg == 1:
-        if not center_of_mass:
-            return 0.5 * multiplier * (min_sq + 2.0) * np.exp(-min_sq)
+        elif deg == 1:
+            return 0.5 * multiplier * (min_sq ** 2 + 2.0 * min_sq + 2.0) * np.exp(-min_sq)
         else:
-            return 0.5 * multiplier * ((min_sq ** 2) + 2.0 * min_sq + 1.0) * np.exp(-min_sq)
+            min_g = min_sq ** 0.5
+            f = lambda g: raw_crosssection_diss_rigid_sphere(g, T, sigma, molecule_vibr, molecule_diss,
+                                                             center_of_mass, vl_dependent)\
+                          * (g ** (3.0 + 2.0 * deg)) * np.exp(-g ** 2)
+            if not nokt:
+                return ((constants.k * T / (2 * constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
+            else:
+                return ((0.5 / (constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
     else:
-        raise KineticlibError('Cannot calculated generalized dissociation omega integral of degree ' + str(deg))
+        min_g = min_sq ** 0.5
+        f = lambda g: raw_crosssection_diss_rigid_sphere(g, T, sigma, molecule_vibr, molecule_diss,
+                                                         center_of_mass, vl_dependent)\
+                      * (g ** (3.0 + 2.0 * deg)) * np.exp(-g ** 2)
+        if not nokt:
+            return ((constants.k * T / (2 * constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
+        else:
+            return ((0.5 / (constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
 
 
 def raw_elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
@@ -1191,7 +1259,6 @@ def raw_vv_collisions(T: float, sigma: float, mass: float, beta: float, vssc: fl
     -------
     np.ndarray
         An array containing the averaged quantities listed above (in the same order)
-
     """
     result = np.zeros(12)
 
